rdf_vocabulary_to_dart library

This library exposes the builder factory for generating Dart classes from RDF vocabulary namespace IRIs.

Classes

FileVocabularySource
Vocabulary source that loads from a file.
UrlVocabularySource
Vocabulary source that loads from a URL.
VocabularySource
Base class for vocabulary sources.

Constants

fallbackOutputDir → const String
fallbackVocabJsonPath → const String

Functions

getBuildExtensions(Map<String, dynamic> config) Map<String, List<String>>
Returns the build extensions for the vocabulary builder based on the given options. This is used for dynamic configuration in the builder's build.yaml.
rdfVocabularyToDart(BuilderOptions options) → Builder
Creates a vocabulary to Dart code generator with the given options.